-- GLOBALS

dgp_Frame_IsMoving = false -- Is the frame currently moving

dgp_Filtered_Guild_Members = {} -- Variable to hold the filtered guild members
dgp_Selected_Guild_Members = {} -- Variable to hold selected guild members

dgp_List_Position = 1 -- Position of the filter list

dgp_Full_Guild = 0 -- Is this a full guild run

dgp_Points_Text = "" -- The text in the custom points editbox

-- For the wait function (http://www.wowwiki.com/Wait)
local waitTable = {};
local waitFrame = nil;

-- Point allocations
local dgp_Scenario_Points = 5
local dgp_Dungeon_Points = 10
local dgp_OldRaid_Points = 25
local dgp_LFR_Points = 25
local dgp_Raid_Points = 50
local dgp_Invite_Points = 10

-- Init variable/function for the dropbox menu
local dgpFilterDropboxInit = function()
	
	-- Add the menu buttons
	local info = UIDropDownMenu_CreateInfo()
	info.text = "All Guild Members"
	info.value = "All"
	info.func = function(self)
			dgpFilterDropboxChangeValue("All") -- Call this function when clicked
			dgpFilterPlayers() -- Update the filtered guild members
			dgpUpdateList() -- Show the new filtered list
		end
	UIDropDownMenu_AddButton(info)
	
	-- Button 2
	info = {}
	info.text = "Online Guild Members"
	info.value = "Online"
	info.func = function(self)
			dgpFilterDropboxChangeValue("Online") -- Call this function when clicked
			dgpFilterPlayers() -- Update the filtered guild members
			dgpUpdateList() -- Show the new filtered list
		end
	UIDropDownMenu_AddButton(info)
	
	-- Button 3
	info = {}
	info.text = "Party/Raid Guild Members"
	info.value = "Party"
	info.func = function(self)
			dgpFilterDropboxChangeValue("Party") -- Call this function when clicked
			dgpFilterPlayers() -- Update the filtered guild members
			dgpUpdateList() -- Show the new filtered list
		end
	UIDropDownMenu_AddButton(info)	
	
	-- Button 4
	info = {}
	info.text = "Selected Guild Members"
	info.value = "Selected"
	info.func = function(self)
			dgpFilterDropboxChangeValue("Selected") -- Call this function when clicked
			dgpFilterPlayers() -- Update the filtered guild members
			dgpUpdateList() -- Show the new filtered list
		end
	UIDropDownMenu_AddButton(info)	
end -- dgpFilterDropboxInit

-- END GLOBALS

-- FRAMES

-- ** Main frame **
local dgp_Frame = CreateFrame("Frame", nil, UIParent) -- Create the Draqisfang Guild Points (dgp) parent frame
	
	-- Register events with the frame
	dgp_Frame:RegisterEvent("ADDON_LOADED") -- Triggered when saved variables are loaded
	dgp_Frame:RegisterEvent("PLAYER_LOGOUT") -- Triggered when the game is about to log out

	-- Set the frame attributes
	dgp_Frame:SetFrameStrata("HIGH") -- Set the frame above most of the UI
	dgp_Frame:SetFrameLevel(11) -- Set the display layer
		-- Size and position are calculated by dgp_Resize_Frames() after the addon loads

	-- Set the texture of the parent frame	
	dgp_Frame:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Background",
		edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
		tile = false, tileSize = 0, edgeSize = 16,
		insets = { left = 4, right = 4, top = 4, bottom = 4} })

	-- Allow the frame to move
	dgp_Frame:SetMovable(true)

	-- Allow mouse interaction
	dgp_Frame:EnableMouse(true)
	
	-- Start with the parent window hidden
	dgp_Frame:Hide()
	
	-- ** Fade out frame **
	local dgp_Fade_Frame = CreateFrame("Button", nil, dgp_Frame) -- Create a frame for fading the addon
	
		-- Set the frame attributes
		dgp_Fade_Frame:SetFrameStrata("HIGH") -- Set the frame above most of the UI
		dgp_Fade_Frame:SetFrameLevel(1) -- Hide the frame behind the rest of the addon by default
			-- Size and position are calculated by dgp_Resize_Frames() after the addon loads
		
		-- Set the frame texture
		dgp_Fade_Frame.texture = dgp_Fade_Frame:CreateTexture()
		dgp_Fade_Frame.texture:SetAllPoints(dgp_Fade_Frame)
		dgp_Fade_Frame.texture:SetTexture(0.0, 0.0, 0.0, 0.8)
		
	-- ** End Fade Frame**
	
	-- ** Title frame (Top left of main frame) **
	local dgp_Title_Frame = CreateFrame("Button", nil, dgp_Frame) -- Create the Filter frame and attach it to the main frame
	-- This has been changed from a frame to a button to enable click and drag.
	
		-- Set the frame attributes
		dgp_Title_Frame:SetFrameStrata("HIGH") -- Set the frame above most of the UI
		dgp_Title_Frame:SetFrameLevel(12) -- Set the display layer
			-- Size and position are calculated by dgp_Resize_Frames() after the addon loads
		
		-- Add a title to the addon window
		dgp_Title_Frame.text = dgp_Title_Frame:CreateFontString(nil, "MEDIUM", "GameFontNormal")
		dgp_Title_Frame.text:SetAllPoints()
		dgp_Title_Frame.text:SetText("Draqisfang Guild Points")
		
		-- Set the texture of the filter frame
		dgp_Title_Frame:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Title-Frame-Background",
			edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
			tile = false, tileSize = 0, edgeSize = 16,
			insets = { left = 4, right = 4, top = 4, bottom = 4} })
		
		-- Register the frame for mouse clicks and define the action
		dgp_Title_Frame:RegisterForClicks("LeftButtonDown", "LeftButtonUp") -- Left button up and down are considered clicks
		dgp_Title_Frame:SetScript("OnClick", function(self)  dgp_Toggle_Move() end) -- Toggle UI movement when the frame is clicked
		
	-- ** End Title frame **
		
		
	-- ** Close button (Top right of main frame) **
	local dgp_Close_Button = CreateFrame("Button", nil, dgp_Frame) -- Create the Close Button frame and attach it to the main frame
		
		-- Set the button attributes
		dgp_Close_Button:SetFrameStrata("HIGH") -- Set the frame above most of the UI
		dgp_Close_Button:SetFrameLevel(12) -- Set the display layer
			-- Size and position are calculated by dgp_Resize_Frames() after the addon loads
			
		-- Set the texture of the close button
		-- Border
		dgp_Close_Button:SetBackdrop({ bgFile = nil,
			edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
			tile = false, tileSize = 0, edgeSize = 16,
			insets = { left = 0, right = 0, top = 0, bottom = 0} })
		dgp_Close_Button:SetNormalTexture("Interface\\Addons\\GuildPoints\\Images\\Close-Button-Background")
		dgp_Close_Button:SetPushedTexture("Interface\\Addons\\GuildPoints\\Images\\Close-Button-Pressed")
		dgp_Close_Button:SetHighlightTexture("Interface\\Addons\\GuildPoints\\Images\\Close-Button-Highlight")
	
		-- Register the action for clicks
		dgp_Close_Button:SetScript("OnClick", function(self) dgpHide() end)
	
	-- ** End Close button **
	
	
	-- ** Bottom Frame (Everything below the title in the main frame) **
	local dgp_Bottom_Frame = CreateFrame("Button", nil, dgp_Frame) -- Create the bottom segment and attach it to the main frame
	-- This is made as a button to enable dragging, same as the title frame
		
		-- Set the frame attributes
		dgp_Bottom_Frame:SetFrameStrata("HIGH") -- Set the frame above most of the UI
		dgp_Bottom_Frame:SetFrameLevel(12) -- Set the display layer
			-- Size and poistion are calculated by dgp_Resize_Frames() after the addon loads
			
		-- Set the texture of the bottom frame
		dgp_Bottom_Frame:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Title-Frame-Background",
			edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
			tile = false, tileSize = 0, edgeSize = 16,
			insets = { left = 4, right = 4, top = 4, bottom = 4} })
		
		-- ** Filter Editbox (Top Right of the 'Bottom Frame')
		local dgp_Filter_Editbox = CreateFrame("EditBox", nil, dgp_Bottom_Frame)
			-- Set the font for the editbox
			dgp_Filter_Editbox:SetFontObject("GameFontHighlight")
			
			-- Turn off autofocus to stop the box keeping focus
			dgp_Filter_Editbox:SetAutoFocus(false)
			
			-- Set the editbox attributes
			dgp_Filter_Editbox:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Filter_Editbox:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frame()
				
			-- Set the texture of the filter editbox
			dgp_Filter_Editbox:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Title-Frame-Background",
				edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
				tile = false, tileSize = 0, edgeSize = 16,
				insets = { left = 4, right = 4, top = 4, bottom = 4} })
			
			dgp_Filter_Editbox:SetMaxLetters(30)
			dgp_Filter_Editbox:SetTextInsets( 5, 5, 2, 2)
			
			-- Register an action for enter
			dgp_Filter_Editbox:SetScript("OnEnterPressed", function(self) dgpClearFilterFocus() end)
			-- Register an action for the text changing
			dgp_Filter_Editbox:SetScript("OnTextChanged", function(self) dgpFilterPlayers()
				dgpUpdateList()
				end)
			
		-- ** End Filter editbox **
		
		-- ** Filter Edibox Label ( Left of the  Filter Editbox)
		local dgp_Filter_Editbox_Label = CreateFrame("Frame", nil, dgp_Bottom_Frame)
			
			-- Set the frame attributes
			dgp_Filter_Editbox_Label:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Filter_Editbox_Label:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frames() after the addon loads
		
			-- Add a title to the addon window
			dgp_Filter_Editbox_Label.text = dgp_Filter_Editbox_Label:CreateFontString(nil, "MEDIUM", "GameFontNormal")
			dgp_Filter_Editbox_Label.text:SetAllPoints()
			dgp_Filter_Editbox_Label.text:SetText("Filter by name:")
		
		-- ** End Filter Editbox Label
		
		-- ** Filter DropBox (Beneath the Filter Editbox)
		local dgp_Filter_Dropbox = CreateFrame("Button", "Filter_Dropbox", dgp_Bottom_Frame, "UIDropDownMenuTemplate")
			
			-- Set the dropbox attributes
			dgp_Filter_Dropbox:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Filter_Dropbox:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frame()
			
			UIDropDownMenu_Initialize(dgp_Filter_Dropbox, dgpFilterDropboxInit) -- Initialise the dropbox
		
			UIDropDownMenu_SetSelectedID(dgp_Filter_Dropbox, 1) -- Set the default menu selection
			
			UIDropDownMenu_JustifyText(dgp_Filter_Dropbox, "LEFT") -- Set the text justification
			
		-- ** End Filter dropbox
		
		-- ** Filter Dropbox Label ( Left of the  Filter Dropbox)
		local dgp_Filter_Dropbox_Label = CreateFrame("Frame", nil, dgp_Bottom_Frame)
			
			-- Set the frame attributes
			dgp_Filter_Dropbox_Label:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Filter_Dropbox_Label:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frames() after the addon loads
		
			-- Add a title to the addon window
			dgp_Filter_Dropbox_Label.text = dgp_Filter_Dropbox_Label:CreateFontString(nil, "MEDIUM", "GameFontNormal")
			dgp_Filter_Dropbox_Label.text:SetAllPoints()
			dgp_Filter_Dropbox_Label.text:SetText("Filter by type:")
		
		-- ** End Filter Dropbox Label
		
		-- ** Player Listbox (Beneath the Filter Dropbox, to the left side of the frame)
		local dgp_Player_Listbox = CreateFrame("Frame", nil, dgp_Bottom_Frame)
			
			-- Set the listbox attributes
			dgp_Player_Listbox:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Player_Listbox:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frame()
				
			-- Set the texture of the player listbox
			dgp_Player_Listbox:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Title-Frame-Background",
				edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
				tile = false, tileSize = 0, edgeSize = 16,
				insets = { left = 4, right = 4, top = 4, bottom = 4} })
			
			-- ** Player Listbox Buttons
			local dgp_Player_Listbox_Button1_1 = CreateFrame("Button", "dgpButton1_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button1_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button1_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button1_1.texture = dgp_Player_Listbox_Button1_1:CreateTexture()
				dgp_Player_Listbox_Button1_1.texture:SetAllPoints(dgp_Player_Listbox_Button1_1)
				dgp_Player_Listbox_Button1_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button1_1.text = dgp_Player_Listbox_Button1_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button1_1.text:SetAllPoints()
				dgp_Player_Listbox_Button1_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(1) end)
			local dgp_Player_Listbox_Button1_2 = CreateFrame("Button", "dgpButton1_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button1_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button1_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button1_2.texture = dgp_Player_Listbox_Button1_2:CreateTexture()
				dgp_Player_Listbox_Button1_2.texture:SetAllPoints(dgp_Player_Listbox_Button1_2)
				dgp_Player_Listbox_Button1_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button1_2.text = dgp_Player_Listbox_Button1_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button1_2.text:SetAllPoints()
				dgp_Player_Listbox_Button1_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(1) end)
				
			local dgp_Player_Listbox_Button2_1 = CreateFrame("Button", "dgpButton2_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button2_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button2_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button2_1.texture = dgp_Player_Listbox_Button2_1:CreateTexture()
				dgp_Player_Listbox_Button2_1.texture:SetAllPoints(dgp_Player_Listbox_Button2_1)
				dgp_Player_Listbox_Button2_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button2_1.text = dgp_Player_Listbox_Button2_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button2_1.text:SetAllPoints()
				dgp_Player_Listbox_Button2_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(2) end)
			local dgp_Player_Listbox_Button2_2 = CreateFrame("Button", "dgpButton2_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button2_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button2_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button2_2.texture = dgp_Player_Listbox_Button2_2:CreateTexture()
				dgp_Player_Listbox_Button2_2.texture:SetAllPoints(dgp_Player_Listbox_Button2_2)
				dgp_Player_Listbox_Button2_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button2_2.text = dgp_Player_Listbox_Button2_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button2_2.text:SetAllPoints()
				dgp_Player_Listbox_Button2_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(2) end)
				
			local dgp_Player_Listbox_Button3_1 = CreateFrame("Button", "dgpButton3_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button3_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button3_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button3_1.texture = dgp_Player_Listbox_Button3_1:CreateTexture()
				dgp_Player_Listbox_Button3_1.texture:SetAllPoints(dgp_Player_Listbox_Button3_1)
				dgp_Player_Listbox_Button3_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button3_1.text = dgp_Player_Listbox_Button3_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button3_1.text:SetAllPoints()
				dgp_Player_Listbox_Button3_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(3) end)
			local dgp_Player_Listbox_Button3_2 = CreateFrame("Button", "dgpButton3_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button3_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button3_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button3_2.texture = dgp_Player_Listbox_Button3_2:CreateTexture()
				dgp_Player_Listbox_Button3_2.texture:SetAllPoints(dgp_Player_Listbox_Button3_2)
				dgp_Player_Listbox_Button3_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button3_2.text = dgp_Player_Listbox_Button3_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button3_2.text:SetAllPoints()
				dgp_Player_Listbox_Button3_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(3) end)
				
			local dgp_Player_Listbox_Button4_1 = CreateFrame("Button", "dgpButton4_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button4_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button4_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button4_1.texture = dgp_Player_Listbox_Button4_1:CreateTexture()
				dgp_Player_Listbox_Button4_1.texture:SetAllPoints(dgp_Player_Listbox_Button4_1)
				dgp_Player_Listbox_Button4_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button4_1.text = dgp_Player_Listbox_Button4_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button4_1.text:SetAllPoints()
				dgp_Player_Listbox_Button4_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(4) end)
			local dgp_Player_Listbox_Button4_2 = CreateFrame("Button", "dgpButton4_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button4_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button4_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button4_2.texture = dgp_Player_Listbox_Button4_2:CreateTexture()
				dgp_Player_Listbox_Button4_2.texture:SetAllPoints(dgp_Player_Listbox_Button4_2)
				dgp_Player_Listbox_Button4_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button4_2.text = dgp_Player_Listbox_Button4_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button4_2.text:SetAllPoints()
				dgp_Player_Listbox_Button4_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(4) end)
				
			local dgp_Player_Listbox_Button5_1 = CreateFrame("Button", "dgpButton5_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button5_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button5_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button5_1.texture = dgp_Player_Listbox_Button5_1:CreateTexture()
				dgp_Player_Listbox_Button5_1.texture:SetAllPoints(dgp_Player_Listbox_Button5_1)
				dgp_Player_Listbox_Button5_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button5_1.text = dgp_Player_Listbox_Button5_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button5_1.text:SetAllPoints()
				dgp_Player_Listbox_Button5_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(5) end)
			local dgp_Player_Listbox_Button5_2 = CreateFrame("Button", "dgpButton5_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button5_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button5_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button5_2.texture = dgp_Player_Listbox_Button5_2:CreateTexture()
				dgp_Player_Listbox_Button5_2.texture:SetAllPoints(dgp_Player_Listbox_Button5_2)
				dgp_Player_Listbox_Button5_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button5_2.text = dgp_Player_Listbox_Button5_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button5_2.text:SetAllPoints()
				dgp_Player_Listbox_Button5_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(5) end)
				
			local dgp_Player_Listbox_Button6_1 = CreateFrame("Button", "dgpButton6_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button6_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button6_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button6_1.texture = dgp_Player_Listbox_Button6_1:CreateTexture()
				dgp_Player_Listbox_Button6_1.texture:SetAllPoints(dgp_Player_Listbox_Button6_1)
				dgp_Player_Listbox_Button6_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button6_1.text = dgp_Player_Listbox_Button6_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button6_1.text:SetAllPoints()
				dgp_Player_Listbox_Button6_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(6) end)
			local dgp_Player_Listbox_Button6_2 = CreateFrame("Button", "dgpButton6_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button6_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button6_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button6_2.texture = dgp_Player_Listbox_Button6_1:CreateTexture()
				dgp_Player_Listbox_Button6_2.texture = dgp_Player_Listbox_Button6_2:CreateTexture()
				dgp_Player_Listbox_Button6_2.texture:SetAllPoints(dgp_Player_Listbox_Button6_2)
				dgp_Player_Listbox_Button6_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button6_2.text = dgp_Player_Listbox_Button6_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button6_2.text:SetAllPoints()
				dgp_Player_Listbox_Button6_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(6) end)
				
			local dgp_Player_Listbox_Button7_1 = CreateFrame("Button", "dgpButton7_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button7_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button7_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button7_1.texture = dgp_Player_Listbox_Button7_1:CreateTexture()
				dgp_Player_Listbox_Button7_1.texture:SetAllPoints(dgp_Player_Listbox_Button7_1)
				dgp_Player_Listbox_Button7_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button7_1.text = dgp_Player_Listbox_Button7_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button7_1.text:SetAllPoints()
				dgp_Player_Listbox_Button7_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(7) end)
			local dgp_Player_Listbox_Button7_2 = CreateFrame("Button", "dgpButton7_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button7_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button7_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button7_2.texture = dgp_Player_Listbox_Button7_2:CreateTexture()
				dgp_Player_Listbox_Button7_2.texture:SetAllPoints(dgp_Player_Listbox_Button7_2)
				dgp_Player_Listbox_Button7_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button7_2.text = dgp_Player_Listbox_Button7_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button7_2.text:SetAllPoints()
				dgp_Player_Listbox_Button7_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(7) end)
				
			local dgp_Player_Listbox_Button8_1 = CreateFrame("Button", "dgpButton8_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button8_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button8_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button8_1.texture = dgp_Player_Listbox_Button8_1:CreateTexture()
				dgp_Player_Listbox_Button8_1.texture:SetAllPoints(dgp_Player_Listbox_Button8_1)
				dgp_Player_Listbox_Button8_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button8_1.text = dgp_Player_Listbox_Button8_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button8_1.text:SetAllPoints()
				dgp_Player_Listbox_Button8_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(8) end)
			local dgp_Player_Listbox_Button8_2 = CreateFrame("Button", "dgpButton8_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button8_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button8_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button8_2.texture = dgp_Player_Listbox_Button8_2:CreateTexture()
				dgp_Player_Listbox_Button8_2.texture:SetAllPoints(dgp_Player_Listbox_Button8_2)
				dgp_Player_Listbox_Button8_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button8_2.text = dgp_Player_Listbox_Button8_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button8_2.text:SetAllPoints()
				dgp_Player_Listbox_Button8_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(8) end)
				
			local dgp_Player_Listbox_Button9_1 = CreateFrame("Button", "dgpButton9_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button9_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button9_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button9_1.texture = dgp_Player_Listbox_Button9_1:CreateTexture()
				dgp_Player_Listbox_Button9_1.texture:SetAllPoints(dgp_Player_Listbox_Button9_1)
				dgp_Player_Listbox_Button9_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button9_1.text = dgp_Player_Listbox_Button9_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button9_1.text:SetAllPoints()
				dgp_Player_Listbox_Button9_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(9) end)
			local dgp_Player_Listbox_Button9_2 = CreateFrame("Button", "dgpButton9_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button9_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button9_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button9_2.texture = dgp_Player_Listbox_Button9_2:CreateTexture()
				dgp_Player_Listbox_Button9_2.texture:SetAllPoints(dgp_Player_Listbox_Button9_2)
				dgp_Player_Listbox_Button9_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button9_2.text = dgp_Player_Listbox_Button9_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button9_2.text:SetAllPoints()
				dgp_Player_Listbox_Button9_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(9) end)
				
			local dgp_Player_Listbox_Button10_1 = CreateFrame("Button", "dgpButton10_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button10_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button10_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button10_1.texture = dgp_Player_Listbox_Button10_1:CreateTexture()
				dgp_Player_Listbox_Button10_1.texture:SetAllPoints(dgp_Player_Listbox_Button10_1)
				dgp_Player_Listbox_Button10_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button10_1.text = dgp_Player_Listbox_Button10_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button10_1.text:SetAllPoints()
				dgp_Player_Listbox_Button10_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(10) end)
			local dgp_Player_Listbox_Button10_2 = CreateFrame("Button", "dgpButton10_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button10_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button10_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button10_2.texture = dgp_Player_Listbox_Button10_2:CreateTexture()
				dgp_Player_Listbox_Button10_2.texture:SetAllPoints(dgp_Player_Listbox_Button10_2)
				dgp_Player_Listbox_Button10_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button10_2.text = dgp_Player_Listbox_Button10_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button10_2.text:SetAllPoints()
				dgp_Player_Listbox_Button10_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(10) end)
				
			local dgp_Player_Listbox_Button11_1 = CreateFrame("Button", "dgpButton11_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button11_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button11_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button11_1.texture = dgp_Player_Listbox_Button11_1:CreateTexture()
				dgp_Player_Listbox_Button11_1.texture:SetAllPoints(dgp_Player_Listbox_Button11_1)
				dgp_Player_Listbox_Button11_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button11_1.text = dgp_Player_Listbox_Button11_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button11_1.text:SetAllPoints()
				dgp_Player_Listbox_Button11_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(11) end)
			local dgp_Player_Listbox_Button11_2 = CreateFrame("Button", "dgpButton11_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button11_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button11_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button11_2.texture = dgp_Player_Listbox_Button11_2:CreateTexture()
				dgp_Player_Listbox_Button11_2.texture:SetAllPoints(dgp_Player_Listbox_Button11_2)
				dgp_Player_Listbox_Button11_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button11_2.text = dgp_Player_Listbox_Button11_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button11_2.text:SetAllPoints()
				dgp_Player_Listbox_Button11_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(11) end)
				
			local dgp_Player_Listbox_Button12_1 = CreateFrame("Button", "dgpButton12_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button12_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button12_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button12_1.texture = dgp_Player_Listbox_Button12_1:CreateTexture()
				dgp_Player_Listbox_Button12_1.texture:SetAllPoints(dgp_Player_Listbox_Button12_1)
				dgp_Player_Listbox_Button12_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button12_1.text = dgp_Player_Listbox_Button12_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button12_1.text:SetAllPoints()
				dgp_Player_Listbox_Button12_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(12) end)
			local dgp_Player_Listbox_Button12_2 = CreateFrame("Button", "dgpButton12_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button12_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button12_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button12_2.texture = dgp_Player_Listbox_Button12_2:CreateTexture()
				dgp_Player_Listbox_Button12_2.texture:SetAllPoints(dgp_Player_Listbox_Button12_2)
				dgp_Player_Listbox_Button12_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button12_2.text = dgp_Player_Listbox_Button12_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button12_2.text:SetAllPoints()
				dgp_Player_Listbox_Button12_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(12) end)
				
			local dgp_Player_Listbox_Button13_1 = CreateFrame("Button", "dgpButton13_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button13_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button13_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button13_1.texture = dgp_Player_Listbox_Button13_1:CreateTexture()
				dgp_Player_Listbox_Button13_1.texture:SetAllPoints(dgp_Player_Listbox_Button13_1)
				dgp_Player_Listbox_Button13_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button13_1.text = dgp_Player_Listbox_Button13_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button13_1.text:SetAllPoints()
				dgp_Player_Listbox_Button13_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(13) end)
			local dgp_Player_Listbox_Button13_2 = CreateFrame("Button", "dgpButton13_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button13_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button13_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button13_2.texture = dgp_Player_Listbox_Button13_2:CreateTexture()
				dgp_Player_Listbox_Button13_2.texture:SetAllPoints(dgp_Player_Listbox_Button13_2)
				dgp_Player_Listbox_Button13_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button13_2.text = dgp_Player_Listbox_Button13_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button13_2.text:SetAllPoints()
				dgp_Player_Listbox_Button13_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(13) end)
				
			local dgp_Player_Listbox_Button14_1 = CreateFrame("Button", "dgpButton14_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button14_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button14_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button14_1.texture = dgp_Player_Listbox_Button14_1:CreateTexture()
				dgp_Player_Listbox_Button14_1.texture:SetAllPoints(dgp_Player_Listbox_Button14_1)
				dgp_Player_Listbox_Button14_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button14_1.text = dgp_Player_Listbox_Button14_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button14_1.text:SetAllPoints()
				dgp_Player_Listbox_Button14_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(14) end)
			local dgp_Player_Listbox_Button14_2 = CreateFrame("Button", "dgpButton14_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button14_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button14_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button14_2.texture = dgp_Player_Listbox_Button14_2:CreateTexture()
				dgp_Player_Listbox_Button14_2.texture:SetAllPoints(dgp_Player_Listbox_Button14_2)
				dgp_Player_Listbox_Button14_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button14_2.text = dgp_Player_Listbox_Button14_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button14_2.text:SetAllPoints()
				dgp_Player_Listbox_Button14_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(14) end)
				
			local dgp_Player_Listbox_Button15_1 = CreateFrame("Button", "dgpButton15_1", dgp_Player_Listbox)
				dgp_Player_Listbox_Button15_1:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button15_1:SetFrameLevel(14)
				dgp_Player_Listbox_Button15_1.texture = dgp_Player_Listbox_Button15_1:CreateTexture()
				dgp_Player_Listbox_Button15_1.texture:SetAllPoints(dgp_Player_Listbox_Button15_1)
				dgp_Player_Listbox_Button15_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button15_1.text = dgp_Player_Listbox_Button15_1:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button15_1.text:SetAllPoints()
				dgp_Player_Listbox_Button15_1:SetScript("OnClick", function(self) dgpToggleSelectPlayer(15) end)
			local dgp_Player_Listbox_Button15_2 = CreateFrame("Button", "dgpButton15_2", dgp_Player_Listbox)
				dgp_Player_Listbox_Button15_2:SetFrameStrata("HIGH")
				dgp_Player_Listbox_Button15_2:SetFrameLevel(14)
				dgp_Player_Listbox_Button15_2.texture = dgp_Player_Listbox_Button15_2:CreateTexture()
				dgp_Player_Listbox_Button15_2.texture:SetAllPoints(dgp_Player_Listbox_Button15_2)
				dgp_Player_Listbox_Button15_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Player_Listbox_Button15_2.text = dgp_Player_Listbox_Button15_2:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Player_Listbox_Button15_2.text:SetAllPoints()
				dgp_Player_Listbox_Button15_2:SetScript("OnClick", function(self) dgpToggleSelectPlayer(15) end)
						
			-- ** End Player Listbox Buttons
			
		-- ** End Player Listbox **
		
		-- ** Player Listbox Scrollbar
		local dgp_Player_Listbox_Slider = CreateFrame("Slider", "PlayerListboxSlider", dgp_Bottom_Frame, "OptionsSliderTemplate")
			
			-- Set the listbox scrollbar attributes
			dgp_Player_Listbox_Slider:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Player_Listbox_Slider:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frame()
				
			getglobal("PlayerListboxSliderLow"):SetText("") -- Remove the Low label
			getglobal("PlayerListboxSliderHigh"):SetText("") -- Remove the High label

			dgp_Player_Listbox_Slider:SetOrientation("VERTICAL") -- Change to a vertical orientation
			dgp_Player_Listbox_Slider:SetMinMaxValues(1, 1) -- Set default min/max value
			dgp_Player_Listbox_Slider:SetValue(1) -- Set the slider value to the top
			dgp_Player_Listbox_Slider:SetValueStep(1) -- Set the minimum step value
			
			dgp_Player_Listbox_Slider:SetScript("OnValueChanged", function(self)
				dgp_List_Position = dgp_Player_Listbox_Slider:GetValue()
				dgpUpdateList()
				end)
				
		-- ** End Player Listbox Scrollbar **
		
		-- ** Button Frame
		local dgp_Button_Frame = CreateFrame("Frame", nil, dgp_Bottom_Frame)
		
			-- Set the button frame attributes
			dgp_Button_Frame:SetFrameStrata("HIGH") -- Set the frame above most of the UI
			dgp_Button_Frame:SetFrameLevel(13) -- Set the display layer
				-- Size and position are calculated by dgp_Resize_Frame()
				
			-- Set the texture of the  button frame
				dgp_Button_Frame:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Title-Frame-Background",
					edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
					tile = false, tileSize = 0, edgeSize = 16,
					insets = { left = 4, right = 4, top = 4, bottom = 4} })
			
			-- ** Button Frame Buttons
			
			local dgp_Button_Modifiers_Title = CreateFrame("Button", "modifiersTitleButton", dgp_Button_Frame)
				dgp_Button_Modifiers_Title:SetFrameStrata("HIGH")
				dgp_Button_Modifiers_Title:SetFrameLevel(14) 
				dgp_Button_Modifiers_Title.text = dgp_Button_Modifiers_Title:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Modifiers_Title.text:SetAllPoints()
				dgp_Button_Modifiers_Title.text:SetTextColor(0.41, 0.80, 0.94, 1.0)
				dgp_Button_Modifiers_Title.text:SetText("Modifiers")
				
			local dgp_Button_Full_Guild = CreateFrame("Button", "fullGuildButton", dgp_Button_Frame)
				dgp_Button_Full_Guild:SetFrameStrata("HIGH")
				dgp_Button_Full_Guild:SetFrameLevel(14) 
				dgp_Button_Full_Guild.texture = dgp_Button_Full_Guild:CreateTexture()
				dgp_Button_Full_Guild.texture:SetAllPoints(dgp_Button_Full_Guild)
				dgp_Button_Full_Guild.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Full_Guild.text = dgp_Button_Full_Guild:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Full_Guild.text:SetAllPoints()
				dgp_Button_Full_Guild.text:SetText("Full Guild")
				dgp_Button_Full_Guild:SetScript("OnClick", function(self) dgpToggleFullGuild() end)
				
			local dgp_Button_Groups_Title = CreateFrame("Button", "groupsTitleButton", dgp_Button_Frame)
				dgp_Button_Groups_Title:SetFrameStrata("HIGH")
				dgp_Button_Groups_Title:SetFrameLevel(14) 
				dgp_Button_Groups_Title.text = dgp_Button_Groups_Title:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Groups_Title.text:SetAllPoints()
				dgp_Button_Groups_Title.text:SetTextColor(0.41, 0.80, 0.94, 1.0)
				dgp_Button_Groups_Title.text:SetText("Groups")
				
			local dgp_Button_Scenario = CreateFrame("Button", "scenarioButton", dgp_Button_Frame)
			
				scenario_Pushed_Texture = dgp_Button_Scenario:CreateTexture()
				scenario_Pushed_Texture:SetAllPoints(dgp_Button_Scenario)
				scenario_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Scenario:SetFrameStrata("HIGH")
				dgp_Button_Scenario:SetFrameLevel(14) 
				dgp_Button_Scenario.texture = dgp_Button_Scenario:CreateTexture()
				dgp_Button_Scenario.texture:SetAllPoints(dgp_Button_Scenario)
				dgp_Button_Scenario.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Scenario:SetPushedTexture(scenario_Pushed_Texture)
				dgp_Button_Scenario.text = dgp_Button_Scenario:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Scenario.text:SetAllPoints()
				dgp_Button_Scenario.text:SetText("Scenario")
				dgp_Button_Scenario:SetScript("OnClick", function(self) dgpAddPoints(dgp_Scenario_Points) end)
			
			local dgp_Button_Dungeon = CreateFrame("Button", "dungeonButton", dgp_Button_Frame)
			
				dungeon_Pushed_Texture = dgp_Button_Dungeon:CreateTexture()
				dungeon_Pushed_Texture:SetAllPoints(dgp_Button_Dungeon)
				dungeon_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Dungeon:SetFrameStrata("HIGH")
				dgp_Button_Dungeon:SetFrameLevel(14) 
				dgp_Button_Dungeon.texture = dgp_Button_Dungeon:CreateTexture()
				dgp_Button_Dungeon.texture:SetAllPoints(dgp_Button_Dungeon)
				dgp_Button_Dungeon.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Dungeon:SetPushedTexture(dungeon_Pushed_Texture)
				dgp_Button_Dungeon.text = dgp_Button_Dungeon:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Dungeon.text:SetAllPoints()
				dgp_Button_Dungeon.text:SetText("Dungeon")
				dgp_Button_Dungeon:SetScript("OnClick", function(self) dgpAddPoints(dgp_Dungeon_Points) end)
			
			local dgp_Button_Old_Raid = CreateFrame("Button", "oldRaidButton", dgp_Button_Frame)
			
				oldraid_Pushed_Texture = dgp_Button_Old_Raid:CreateTexture()
				oldraid_Pushed_Texture:SetAllPoints(dgp_Button_Old_Raid)
				oldraid_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Old_Raid:SetFrameStrata("HIGH")
				dgp_Button_Old_Raid:SetFrameLevel(14) 
				dgp_Button_Old_Raid.texture = dgp_Button_Old_Raid:CreateTexture()
				dgp_Button_Old_Raid.texture:SetAllPoints(dgp_Button_Old_Raid)
				dgp_Button_Old_Raid.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Old_Raid:SetPushedTexture(oldraid_Pushed_Texture)
				dgp_Button_Old_Raid.text = dgp_Button_Old_Raid:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Old_Raid.text:SetAllPoints()
				dgp_Button_Old_Raid.text:SetText("Old Raid")
				dgp_Button_Old_Raid:SetScript("OnClick", function(self) dgpAddPoints(dgp_OldRaid_Points) end)

			local dgp_Button_LFR_Boss = CreateFrame("Button", "lfrBossButton", dgp_Button_Frame)
			
				lfr_Pushed_Texture = dgp_Button_LFR_Boss:CreateTexture()
				lfr_Pushed_Texture:SetAllPoints(dgp_Button_LFR_Boss)
				lfr_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_LFR_Boss:SetFrameStrata("HIGH")
				dgp_Button_LFR_Boss:SetFrameLevel(14) 
				dgp_Button_LFR_Boss.texture = dgp_Button_LFR_Boss:CreateTexture()
				dgp_Button_LFR_Boss.texture:SetAllPoints(dgp_Button_LFR_Boss)
				dgp_Button_LFR_Boss.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_LFR_Boss:SetPushedTexture(lfr_Pushed_Texture)
				dgp_Button_LFR_Boss.text = dgp_Button_LFR_Boss:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_LFR_Boss.text:SetAllPoints()
				dgp_Button_LFR_Boss.text:SetText("LFR Boss")
				dgp_Button_LFR_Boss:SetScript("OnClick", function(self) dgpAddPoints(dgp_LFR_Points) end)
				
			local dgp_Button_Raid_Boss = CreateFrame("Button", "RaidBossButton", dgp_Button_Frame)
			
				raid_Pushed_Texture = dgp_Button_Raid_Boss:CreateTexture()
				raid_Pushed_Texture:SetAllPoints(dgp_Button_Raid_Boss)
				raid_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Raid_Boss:SetFrameStrata("HIGH")
				dgp_Button_Raid_Boss:SetFrameLevel(14) 
				dgp_Button_Raid_Boss.texture = dgp_Button_Raid_Boss:CreateTexture()
				dgp_Button_Raid_Boss.texture:SetAllPoints(dgp_Button_Raid_Boss)
				dgp_Button_Raid_Boss.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Raid_Boss:SetPushedTexture(raid_Pushed_Texture)
				dgp_Button_Raid_Boss.text = dgp_Button_Raid_Boss:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Raid_Boss.text:SetAllPoints()
				dgp_Button_Raid_Boss.text:SetText("Raid Boss")
				dgp_Button_Raid_Boss:SetScript("OnClick", function(self) dgpAddPoints(dgp_Raid_Points) end)
			
			local dgp_Button_Other_Title = CreateFrame("Button", "otherTitleButton", dgp_Button_Frame)
				dgp_Button_Other_Title:SetFrameStrata("HIGH")
				dgp_Button_Other_Title:SetFrameLevel(14) 
				dgp_Button_Other_Title.text = dgp_Button_Other_Title:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Other_Title.text:SetAllPoints()
				dgp_Button_Other_Title.text:SetTextColor(0.41, 0.80, 0.94, 1.0)
				dgp_Button_Other_Title.text:SetText("Other")
				
			local dgp_Button_Invite = CreateFrame("Button", "inviteButton", dgp_Button_Frame)
			
				invite_Pushed_Texture = dgp_Button_Invite:CreateTexture()
				invite_Pushed_Texture:SetAllPoints(dgp_Button_Invite)
				invite_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Invite:SetFrameStrata("HIGH")
				dgp_Button_Invite:SetFrameLevel(14) 
				dgp_Button_Invite.texture = dgp_Button_Invite:CreateTexture()
				dgp_Button_Invite.texture:SetAllPoints(dgp_Button_Invite)
				dgp_Button_Invite.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Invite:SetPushedTexture(invite_Pushed_Texture)
				dgp_Button_Invite.text = dgp_Button_Invite:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Invite.text:SetAllPoints()
				dgp_Button_Invite.text:SetText("Invites")
				dgp_Button_Invite:SetScript("OnClick", function(self) dgpAddPoints(dgp_Invite_Points) end)
				
			local dgp_Button_Backup = CreateFrame("Button", "backupButton", dgp_Button_Frame)
			
				backup_Pushed_Texture = dgp_Button_Backup:CreateTexture()
				backup_Pushed_Texture:SetAllPoints(dgp_Button_Backup)
				backup_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Backup:SetFrameStrata("HIGH")
				dgp_Button_Backup:SetFrameLevel(14) 
				dgp_Button_Backup.texture = dgp_Button_Backup:CreateTexture()
				dgp_Button_Backup.texture:SetAllPoints(dgp_Button_Backup)
				dgp_Button_Backup.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Backup:SetPushedTexture(backup_Pushed_Texture)
				dgp_Button_Backup.text = dgp_Button_Backup:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Backup.text:SetAllPoints()
				dgp_Button_Backup.text:SetText("Backup")
				dgp_Button_Backup:SetScript("OnClick", function(self) dgpBackup() end)
				
			local dgp_Button_Custom_Title = CreateFrame("Button", "customTitleButton", dgp_Button_Frame)
				dgp_Button_Custom_Title:SetFrameStrata("HIGH")
				dgp_Button_Custom_Title:SetFrameLevel(14) 
				dgp_Button_Custom_Title.text = dgp_Button_Custom_Title:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Custom_Title.text:SetAllPoints()
				dgp_Button_Custom_Title.text:SetTextColor(0.41, 0.80, 0.94, 1.0)
				dgp_Button_Custom_Title.text:SetText("Custom")
				
			local dgp_Editbox_GP = CreateFrame("EditBox", nil, dgp_Button_Frame)
				dgp_Editbox_GP:SetFontObject("GameFontHighlight")
				dgp_Editbox_GP:SetAutoFocus(false)
				dgp_Editbox_GP:SetFrameStrata("HIGH")
				dgp_Editbox_GP:SetFrameLevel(14) 
				dgp_Editbox_GP:SetBackdrop({ bgFile = "Interface\\AddOns\\GuildPoints\\Images\\Title-Frame-Background",
					edgeFile = "Interface\\AddOns\\GuildPoints\\Images\\Main-Frame-Border",
					tile = false, tileSize = 0, edgeSize = 16,
					insets = { left = 4, right = 4, top = 4, bottom = 4} })
				dgp_Editbox_GP:SetMaxLetters(10)
				dgp_Editbox_GP:SetTextInsets( 5, 5, 2, 2)
				dgp_Editbox_GP:SetScript("OnEnterPressed", function(self) dgpClearGPFocus() end)
				dgp_Editbox_GP:SetScript("OnTextChanged", function(self) -- Check for acceptable entries
						if tonumber(dgp_Editbox_GP:GetText()) == nil then
							if dgp_Editbox_GP:GetText() == "" then
								dgp_Points_Text = dgp_Editbox_GP:GetText()
							else
								dgp_Editbox_GP:SetText(dgp_Points_Text)
							end
						else
							dgp_Points_Text = dgp_Editbox_GP:GetText()
						end
					end)
				
			local dgp_Button_Add = CreateFrame("Button", "addButton", dgp_Button_Frame)
			
				add_Pushed_Texture = dgp_Button_Add:CreateTexture()
				add_Pushed_Texture:SetAllPoints(dgp_Button_Add)
				add_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Add:SetFrameStrata("HIGH")
				dgp_Button_Add:SetFrameLevel(14) 
				dgp_Button_Add.texture = dgp_Button_Add:CreateTexture()
				dgp_Button_Add.texture:SetAllPoints(dgp_Button_Add)
				dgp_Button_Add.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Add:SetPushedTexture(add_Pushed_Texture)
				dgp_Button_Add.text = dgp_Button_Add:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Add.text:SetAllPoints()
				dgp_Button_Add.text:SetText("Add")
				dgp_Button_Add:SetScript("OnClick", function(self) dgpAddPoints( floor( tonumber(dgp_Editbox_GP:GetText()) ) ) end)
				
			local dgp_Button_Subtract = CreateFrame("Button", "subtractButton", dgp_Button_Frame)
			
				subtract_Pushed_Texture = dgp_Button_Subtract:CreateTexture()
				subtract_Pushed_Texture:SetAllPoints(dgp_Button_Subtract)
				subtract_Pushed_Texture:SetTexture(0.1, 0.2, 1.0, 0.25)
				
				dgp_Button_Subtract:SetFrameStrata("HIGH")
				dgp_Button_Subtract:SetFrameLevel(14) 
				dgp_Button_Subtract.texture = dgp_Button_Subtract:CreateTexture()
				dgp_Button_Subtract.texture:SetAllPoints(dgp_Button_Subtract)
				dgp_Button_Subtract.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
				dgp_Button_Subtract:SetPushedTexture(subtract_Pushed_Texture)
				dgp_Button_Subtract.text = dgp_Button_Subtract:CreateFontString(nil, "MEDIUM", "GameFontNormal")
				dgp_Button_Subtract.text:SetAllPoints()
				dgp_Button_Subtract.text:SetText("Subtract")
				dgp_Button_Subtract:SetScript("OnClick", function(self) dgpSubtractPoints( floor( tonumber(dgp_Editbox_GP:GetText()) ) ) end)
				
			-- ** End Button Frame Buttons **
			
		-- ** End Button Frame **
		
	-- ** End Bottom frame **
	
-- ** End Main frame **

-- END FRAMES

		
-- EVENT RECIEVE FUNCTIONS

-- Main frame
function dgp_Frame:OnEvent(event, arg1)
	-- When a addon loaded event is sent, then check if it's for this addon
	if event == "ADDON_LOADED" and arg1 == "GuildPoints" then
		-- Checks for the presence of the 5 backups and initialises them if they do not exist
		if DGPBackupNum1 == nil then
			DGPBackupNum1 = {}
			DGPBackupNum1.date = date("%d/%m/%y %H:%M:%S")
		end
		if DGPBackupNum2 == nil then
			DGPBackupNum2 = {}
			DGPBackupNum2.date = date("%d/%m/%y %H:%M:%S")
		end
		if DGPBackupNum3 == nil then
			DGPBackupNum3 = {}
			DGPBackupNum3.date = date("%d/%m/%y %H:%M:%S")
		end
		if DGPBackupNum4 == nil then
			DGPBackupNum4 = {}
			DGPBackupNum4.date = date("%d/%m/%y %H:%M:%S")
		end
		if DGPBackupNum5 == nil then
			DGPBackupNum5 = {}
			DGPBackupNum5.date = date("%d/%m/%y %H:%M:%S")
		end
		-- Also checks the saved frame sizes and position
		if DGPWidth == nil then
			DGPWidth = 400
		end
		if DGPHeight == nil then
			DGPHeight = 400
		end
		if DGPBottomOffset == nil then
			DGPBottomOffset = 500
		end
		if DGPLeftOffset == nil then
			DGPLeftOffset = 50
		end
		
		-- Now that the frame size and position exists we can set it
		dgp_Resize_Frames()
		
		-- Create the player list
		UIDropDownMenu_SetSelectedValue(dgp_Filter_Dropbox, "All") -- Set the list to show all guld members
		dgpFilterPlayers() -- Update the filtered guild members
		dgpUpdateList() -- Show the new filtered list
		
	end -- ADDON LOADED Guild Points
end -- dgp_Frame:OnEvent	
	
-- SLASH COMMANDS

-- Create and register slash commands
dgp_Frame:SetScript("OnEvent", dgp_Frame.OnEvent) -- Not sure what this exactly does yet, but it doesn't work without it

SLASH_GUILDPOINTS1 = "/dgp" -- Define a slash command to be used in game

-- Define what the slash command does (Not sure how it links to the slash command yet)
function SlashCmdList.GUILDPOINTS(msg)
	dgp_Frame:Show() -- Show the addon window
end -- SlashCmdList.GUILDPOINTS


-- FUNCTIONS

-- This function updates the frame sizes and positions
function dgp_Resize_Frames()
	-- Size and position the  main frame
	dgp_Frame:SetWidth(DGPWidth) -- Parent frame width
	dgp_Frame:SetHeight(DGPHeight) -- Parent frame height
	dgp_Frame:SetPoint("BOTTOM", 0, DGPBottomOffset) -- Offset the parent frame from the top of the screen
	dgp_Frame:SetPoint("LEFT", DGPLeftOffset, 0) -- Offset the parent frame from the left of the screen
		
		-- Size and position the fade frame (Covers the bottom frame)
		dgp_Parent = dgp_Fade_Frame:GetParent() -- Hold a pointer to the parent frame
		dgp_Fade_Frame:SetWidth(dgp_Parent:GetWidth() - 10) -- Fade frame width
		dgp_Fade_Frame:SetHeight(dgp_Parent:GetHeight() - 30) -- Fade frame height
		dgp_Fade_Frame:SetPoint("TOP", 0, -25) -- Position flush with the top of the parent frame
		dgp_Fade_Frame:SetPoint("LEFT", 5, 0) -- Position flush with the left side
		
		-- Size and position the title frame (Top-left of the main frame)
		dgp_Parent = dgp_Title_Frame:GetParent() -- Hold a pointer to the parent frame
		dgp_Title_Frame:SetWidth(dgp_Parent:GetWidth() - 20) -- Title frame width 10 pixels less than the parent frame
		dgp_Title_Frame:SetHeight(25) -- Title frame height 1/10 of the parent frame
		dgp_Title_Frame:SetPoint("TOP", 0, 0) -- Position flush with the top of the parent frame
		dgp_Title_Frame:SetPoint("LEFT", 0, 0) -- Position flush with the left side
		
		-- Size and position the close button (Top-Right of the main frame)
		dgp_Parent = dgp_Close_Button:GetParent() -- Hold a pointer to the parent frame
		dgp_Close_Button:SetWidth(25) -- Close button width is 25
		dgp_Close_Button:SetHeight(25) -- Close button height is 25
		dgp_Close_Button:SetPoint("TOP", 0, 0) -- Position flush with the top of the parent frame
		dgp_Close_Button:SetPoint("RIGHT", 0, 0) -- Position flush with the right side
		
		-- Size and position the bottom frame (Everything below the title frame on the main frame
		dgp_Parent = dgp_Bottom_Frame:GetParent() -- Hold a pointer to the parent frame
		dgp_Bottom_Frame:SetWidth(dgp_Parent:GetWidth()) -- Bottom frame is the same width as the parent frame
		dgp_Bottom_Frame:SetHeight(dgp_Parent:GetHeight() - dgp_Title_Frame:GetHeight() + 5) -- Height is the same as the parent frame minus the title height
		dgp_Bottom_Frame:SetPoint("BOTTOM", 0, 0) -- Position flush with the bottom of the parent frame
		dgp_Bottom_Frame:SetPoint("LEFT", 0, 0) -- Postion flush with the left of the parent frame
		
			-- Size and position the filter editbox (Top right of the bottom frame)
			dgp_Parent = dgp_Filter_Editbox:GetParent() -- Hold a pointer to the parent frame
			dgp_Filter_Editbox:SetWidth(dgp_Parent:GetWidth() - 110) -- Filter editbox is 110 pixels less across than the parent frame
			dgp_Filter_Editbox:SetHeight(25) -- Filter editbox height is 25 pixels
			dgp_Filter_Editbox:SetPoint("TOP", 0, -5) -- Position 5 pixels from the top of the bottom frame
			dgp_Filter_Editbox:SetPoint("RIGHT", -5, 0) -- Position 5 pixels from the right of the bottom frame
			
			-- Size and position the filter editbox label (Left of the filter editbox)
			dgp_Parent = dgp_Filter_Editbox_Label:GetParent() -- Hold a pointer to the parent frame
			dgp_Filter_Editbox_Label:SetWidth(100) -- Filter editbox label width is 100 pixels
			dgp_Filter_Editbox_Label:SetHeight(25) -- Filter editbox label height is 25 pixels
			dgp_Filter_Editbox_Label:SetPoint("TOP", 0, -5) -- Position 5 pixels from the top of the bottom frame
			dgp_Filter_Editbox_Label:SetPoint("LEFT", 5, 0) -- Position 5 pixels from the left of the bottom frame
			
			-- Size and position the filter dropbox (Beneath the filter editbox)
			dgp_Parent = dgp_Filter_Dropbox:GetParent() -- Hold a pointer to the parent frame
			UIDropDownMenu_SetWidth(dgp_Filter_Dropbox, dgp_Parent:GetWidth() - 128) -- Set the dropbox width
			UIDropDownMenu_SetButtonWidth(dgp_Filter_Dropbox, dgp_Parent:GetWidth() - 113) -- Set the dropbox button width
			dgp_Filter_Dropbox:SetWidth(dgp_Parent:GetWidth() - 110) -- Filter dropbox is the same size as the editbox
			dgp_Filter_Dropbox:SetHeight(25) -- Filter dropbox height is 25 pixels
			dgp_Filter_Dropbox:SetPoint("TOP", 0, -30 ) -- Position 5 pixels below the editbox
			dgp_Filter_Dropbox:SetPoint("RIGHT", -22, 0) -- Position 5 pixels from the right of the bottom frame
			
			-- Size and position the filter dropbox label (Left of the filter editbox)
			dgp_Parent = dgp_Filter_Dropbox_Label:GetParent() -- Hold a pointer to the parent frame
			dgp_Filter_Dropbox_Label:SetWidth(100) -- Filter dropbox label width is 100 pixels
			dgp_Filter_Dropbox_Label:SetHeight(25) -- Filter dropbox label height is 25 pixels
			dgp_Filter_Dropbox_Label:SetPoint("TOP", 0, -30) -- Position 5 pixels from the top of the bottom frame
			dgp_Filter_Dropbox_Label:SetPoint("LEFT", 5, 0) -- Position 5 pixels from the left of the bottom frame
			
			-- Size and position the player listbox (Beneath the filter dropbox to the left side of the frame)
			dgp_Parent = dgp_Player_Listbox:GetParent() -- Hold a pointer to the parent frame
			dgp_Player_Listbox:SetWidth(dgp_Parent:GetWidth() * 2/3) -- Player listbox is 2/3 the width of the bottom frame
			dgp_Player_Listbox:SetHeight(dgp_Parent:GetHeight() - 65) -- Player listboxtakes up the remaining height of the bottom frame
			dgp_Player_Listbox:SetPoint("TOP", 0, -60) -- Position 5 pixels below the filter dropbox
			dgp_Player_Listbox:SetPoint("LEFT", 5, 0) -- Position 5 pixels from the left of the bottom frame
			
				-- Size and postion the player listbox buttons
				dgp_Parent = dgp_Player_Listbox_Button1_1:GetParent()
				
				dgp_Player_Listbox_Button1_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button1_1:SetHeight(16)
				dgp_Player_Listbox_Button1_1:SetPoint("TOPLEFT", 4, -8)
				dgp_Player_Listbox_Button1_1:Hide()
				dgp_Player_Listbox_Button1_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button1_2:SetHeight(16)
				dgp_Player_Listbox_Button1_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button1_1:GetWidth() + 4, -8)
				dgp_Player_Listbox_Button1_2:Hide()
				
				dgp_Player_Listbox_Button2_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button2_1:SetHeight(16)
				dgp_Player_Listbox_Button2_1:SetPoint("TOPLEFT", 4, -28)
				dgp_Player_Listbox_Button2_1:Hide()
				dgp_Player_Listbox_Button2_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button2_2:SetHeight(16)
				dgp_Player_Listbox_Button2_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button2_1:GetWidth() + 4, -28)
				dgp_Player_Listbox_Button2_2:Hide()
				
				dgp_Player_Listbox_Button3_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button3_1:SetHeight(16)
				dgp_Player_Listbox_Button3_1:SetPoint("TOPLEFT", 4, -48)
				dgp_Player_Listbox_Button3_1:Hide()
				dgp_Player_Listbox_Button3_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button3_2:SetHeight(16)
				dgp_Player_Listbox_Button3_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button3_1:GetWidth() + 4, -48)
				dgp_Player_Listbox_Button3_2:Hide()
				
				dgp_Player_Listbox_Button4_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button4_1:SetHeight(16)
				dgp_Player_Listbox_Button4_1:SetPoint("TOPLEFT", 4, -68)
				dgp_Player_Listbox_Button4_1:Hide()
				dgp_Player_Listbox_Button4_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button4_2:SetHeight(16)
				dgp_Player_Listbox_Button4_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button4_1:GetWidth() + 4, -68)
				dgp_Player_Listbox_Button4_2:Hide()
				
				dgp_Player_Listbox_Button5_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button5_1:SetHeight(16)
				dgp_Player_Listbox_Button5_1:SetPoint("TOPLEFT", 4, -88)
				dgp_Player_Listbox_Button5_1:Hide()
				dgp_Player_Listbox_Button5_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button5_2:SetHeight(16)
				dgp_Player_Listbox_Button5_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button5_1:GetWidth() + 4, -88)
				dgp_Player_Listbox_Button5_2:Hide()
				
				dgp_Player_Listbox_Button6_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button6_1:SetHeight(16)
				dgp_Player_Listbox_Button6_1:SetPoint("TOPLEFT", 4, -108)
				dgp_Player_Listbox_Button6_1:Hide()
				dgp_Player_Listbox_Button6_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button6_2:SetHeight(16)
				dgp_Player_Listbox_Button6_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button6_1:GetWidth() + 4, -108)
				dgp_Player_Listbox_Button6_2:Hide()
				
				dgp_Player_Listbox_Button7_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button7_1:SetHeight(16)
				dgp_Player_Listbox_Button7_1:SetPoint("TOPLEFT", 4, -128)
				dgp_Player_Listbox_Button7_1:Hide()
				dgp_Player_Listbox_Button7_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button7_2:SetHeight(16)
				dgp_Player_Listbox_Button7_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button7_1:GetWidth() + 4, -128)
				dgp_Player_Listbox_Button7_2:Hide()
				
				dgp_Player_Listbox_Button8_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button8_1:SetHeight(16)
				dgp_Player_Listbox_Button8_1:SetPoint("TOPLEFT", 4, -148)
				dgp_Player_Listbox_Button8_1:Hide()
				dgp_Player_Listbox_Button8_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button8_2:SetHeight(16)
				dgp_Player_Listbox_Button8_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button8_1:GetWidth() + 4, -148)
				dgp_Player_Listbox_Button8_2:Hide()
				
				dgp_Player_Listbox_Button9_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button9_1:SetHeight(16)
				dgp_Player_Listbox_Button9_1:SetPoint("TOPLEFT", 4, -168)
				dgp_Player_Listbox_Button9_1:Hide()
				dgp_Player_Listbox_Button9_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button9_2:SetHeight(16)
				dgp_Player_Listbox_Button9_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button9_1:GetWidth() + 4, -168)
				dgp_Player_Listbox_Button9_2:Hide()
				
				dgp_Player_Listbox_Button10_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button10_1:SetHeight(16)
				dgp_Player_Listbox_Button10_1:SetPoint("TOPLEFT", 4, -188)
				dgp_Player_Listbox_Button10_1:Hide()
				dgp_Player_Listbox_Button10_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button10_2:SetHeight(16)
				dgp_Player_Listbox_Button10_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button10_1:GetWidth() + 4, -188)
				dgp_Player_Listbox_Button10_2:Hide()
				
				dgp_Player_Listbox_Button11_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button11_1:SetHeight(16)
				dgp_Player_Listbox_Button11_1:SetPoint("TOPLEFT", 4, -208)
				dgp_Player_Listbox_Button11_1:Hide()
				dgp_Player_Listbox_Button11_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button11_2:SetHeight(16)
				dgp_Player_Listbox_Button11_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button11_1:GetWidth() + 4, -208)
				dgp_Player_Listbox_Button11_2:Hide()
				
				dgp_Player_Listbox_Button12_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button12_1:SetHeight(16)
				dgp_Player_Listbox_Button12_1:SetPoint("TOPLEFT", 4, -228)
				dgp_Player_Listbox_Button12_1:Hide()
				dgp_Player_Listbox_Button12_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button12_2:SetHeight(16)
				dgp_Player_Listbox_Button12_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button12_1:GetWidth() + 4, -228)
				dgp_Player_Listbox_Button12_2:Hide()
				
				dgp_Player_Listbox_Button13_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button13_1:SetHeight(16)
				dgp_Player_Listbox_Button13_1:SetPoint("TOPLEFT", 4, -248)
				dgp_Player_Listbox_Button13_1:Hide()
				dgp_Player_Listbox_Button13_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button13_2:SetHeight(16)
				dgp_Player_Listbox_Button13_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button13_1:GetWidth() + 4, -248)
				dgp_Player_Listbox_Button13_2:Hide()
				
				dgp_Player_Listbox_Button14_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button14_1:SetHeight(16)
				dgp_Player_Listbox_Button14_1:SetPoint("TOPLEFT", 4, -268)
				dgp_Player_Listbox_Button14_1:Hide()
				dgp_Player_Listbox_Button14_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button14_2:SetHeight(16)
				dgp_Player_Listbox_Button14_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button14_1:GetWidth() + 4, -268)
				dgp_Player_Listbox_Button14_2:Hide()
				
				dgp_Player_Listbox_Button15_1:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button15_1:SetHeight(16)
				dgp_Player_Listbox_Button15_1:SetPoint("TOPLEFT", 4, -288)
				dgp_Player_Listbox_Button15_1:Hide()
				dgp_Player_Listbox_Button15_2:SetWidth((dgp_Parent:GetWidth() - 8)/2)
				dgp_Player_Listbox_Button15_2:SetHeight(16)
				dgp_Player_Listbox_Button15_2:SetPoint("TOPLEFT", dgp_Player_Listbox_Button15_1:GetWidth() + 4, -288)
				dgp_Player_Listbox_Button15_2:Hide()
			
			-- Size and position the Listbox Scrollbar to the right of the listbox
			dgp_Parent = dgp_Player_Listbox_Slider:GetParent() -- Hold a pointer to the parent frame
			dgp_Player_Listbox_Slider:SetWidth(16) -- Set the width to 16 pixels
			dgp_Player_Listbox_Slider:SetHeight(dgp_Player_Listbox:GetHeight() + 4) -- Set the height to the same as the listbox
			dgp_Player_Listbox_Slider:SetPoint("TOP", 0, -58) -- Position 5 pixels below the filter dropbox
			dgp_Player_Listbox_Slider:SetPoint("LEFT", dgp_Player_Listbox:GetWidth() + 3, 0) -- Position 5 pixels from the left of the bottom frame
			
			-- Size and position the Button Frame to the bottom left of the Bottom Frame
			dgp_Parent = dgp_Button_Frame:GetParent() -- Hold a pointer to the parent frame
			dgp_Button_Frame:SetWidth(dgp_Parent:GetWidth() - dgp_Player_Listbox:GetWidth() - dgp_Player_Listbox_Slider:GetWidth() - 8) -- The remaining width of the bottom frame
			dgp_Button_Frame:SetHeight(dgp_Player_Listbox:GetHeight()) -- Same height as the listbox
			dgp_Button_Frame:SetPoint("TOP", 0, -60) -- Same as the listbox
			dgp_Button_Frame:SetPoint("RIGHT", -5, 0) -- 5 Pixels from the right
			
				-- Size and postion the button frame buttons
				dgp_Parent = dgp_Button_Modifiers_Title:GetParent()
				
				dgp_Button_Modifiers_Title:SetWidth(dgp_Parent:GetWidth() - 10)
				dgp_Button_Modifiers_Title:SetHeight(16)
				dgp_Button_Modifiers_Title:SetPoint("TOPLEFT", 5, -5)
				
				dgp_Button_Full_Guild:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Full_Guild:SetHeight(16)
				dgp_Button_Full_Guild:SetPoint("TOPLEFT", 7, -25)
				
				dgp_Button_Groups_Title:SetWidth(dgp_Parent:GetWidth() - 10)
				dgp_Button_Groups_Title:SetHeight(16)
				dgp_Button_Groups_Title:SetPoint("TOPLEFT", 5, -45)
				
				dgp_Button_Scenario:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Scenario:SetHeight(16)
				dgp_Button_Scenario:SetPoint("TOPLEFT", 7, -65)
				
				dgp_Button_Dungeon:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Dungeon:SetHeight(16)
				dgp_Button_Dungeon:SetPoint("TOPLEFT", 7, -85)
				
				dgp_Button_Old_Raid:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Old_Raid:SetHeight(16)
				dgp_Button_Old_Raid:SetPoint("TOPLEFT", 7, -105)
				
				dgp_Button_LFR_Boss:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_LFR_Boss:SetHeight(16)
				dgp_Button_LFR_Boss:SetPoint("TOPLEFT", 7, -125)
				
				dgp_Button_Raid_Boss:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Raid_Boss:SetHeight(16)
				dgp_Button_Raid_Boss:SetPoint("TOPLEFT", 7, -145)
				
				dgp_Button_Other_Title:SetWidth(dgp_Parent:GetWidth() - 10)
				dgp_Button_Other_Title:SetHeight(16)
				dgp_Button_Other_Title:SetPoint("TOPLEFT", 5, -165)
				
				dgp_Button_Invite:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Invite:SetHeight(16)
				dgp_Button_Invite:SetPoint("TOPLEFT", 7, -185)
				
				dgp_Button_Backup:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Backup:SetHeight(16)
				dgp_Button_Backup:SetPoint("TOPLEFT", 7, -205)
				
				dgp_Button_Custom_Title:SetWidth(dgp_Parent:GetWidth() - 10)
				dgp_Button_Custom_Title:SetHeight(16)
				dgp_Button_Custom_Title:SetPoint("TOPLEFT", 5, -225)
				
				dgp_Editbox_GP:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Editbox_GP:SetHeight(21)
				dgp_Editbox_GP:SetPoint("TOPLEFT", 7, -245)
				
				dgp_Button_Add:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Add:SetHeight(16)
				dgp_Button_Add:SetPoint("TOPLEFT", 7, -270)
				
				dgp_Button_Subtract:SetWidth(dgp_Parent:GetWidth() - 14)
				dgp_Button_Subtract:SetHeight(16)
				dgp_Button_Subtract:SetPoint("TOPLEFT", 7, -290)
				
end -- dgp_Resize_Frames


-- Delayed function call (http://www.wowwiki.com/Wait)
function dgp_wait(delay, func, ...)
	if(type(delay)~="number" or type(func)~="function") then
		return false;
	end
	
	if(waitFrame == nil) then
		waitFrame = CreateFrame("Frame","WaitFrame", UIParent);
		waitFrame:SetScript("onUpdate",function (self,elapse)
			local count = #waitTable;
			local i = 1;
			while(i<=count) do
				local waitRecord = tremove(waitTable,i);
				local d = tremove(waitRecord,1);
				local f = tremove(waitRecord,1);
				local p = tremove(waitRecord,1);
				if(d>elapse) then
					tinsert(waitTable,i,{d-elapse,f,p});
					i = i + 1;
				else
					count = count - 1;
					f(unpack(p));
				end
			end
		end);
	end
	tinsert(waitTable,{delay,func,{...}});
	return true;
end -- dgp_wait


-- This is to show the addon windows
function dgpShow()
	dgp_Frame:Show() -- Show the addon window
end -- dgpShow


-- This is to hidw the addon window
function dgpHide()
	dgp_Frame:Hide() -- Hide the addon window
end -- dgpHide


-- This toggles the movement of the parent frame
function dgp_Toggle_Move()
	if dgp_Frame_IsMoving then -- If the frame is flagged as  moving
		dgp_Frame:StopMovingOrSizing() -- Stop moving the main frame
		dgp_Frame_IsMoving = false -- Flag the frame is no longer moving	
		DGPLeftOffset = dgp_Frame:GetLeft() -- Set the new horizontal position
		DGPBottomOffset = dgp_Frame:GetBottom() -- Set the new vertical position
	else -- If the frame is flagged as not moving
		dgp_Frame:StartMoving() -- Start moving the main frame
		dgp_Frame_IsMoving = true -- Flag the frame is now moving	
	end -- If dgp_Frame_IsMoving
end -- dgp_Toggle_Move


 -- Backup the guild public notes (used for storing Guild Points)
function dgpBackup()
	local counter = 1 -- Variable for counting
	
	-- Clear the last backup and store it in a temporary variable (To avoid a memory lose as tables aren't deleted till the game quits)
	wipe(DGPBackupNum5)
	local tempBackup = DGPBackupNum5
	-- Move all previous backups along the chain and delete the oldest
	DGPBackupNum5 = DGPBackupNum4
	DGPBackupNum4 = DGPBackupNum3
	DGPBackupNum3 = DGPBackupNum2
	DGPBackupNum2 = DGPBackupNum1
	
	SetGuildRosterShowOffline(true) -- Make sure offline members are shown
	
	local numMembers = GetNumGuildMembers() -- Retrieve the number of guild members (online number not required)
	
	-- Create a new backup in the first loctation
	
	DGPBackupNum1 = tempBackup -- Reuse the discarded table
	
	-- Cycle through all players in the guild
	while counter <= numMembers do
	
		-- Retrieve the players guild details up to officer note
		local name, rank, rankIndex, level, class, zone, note, officernote = GetGuildRosterInfo(counter)
		
		-- Make sure there is a note already
		if note == "" then -- If not...
			note = "GP: 0"
			if CanEditPublicNote() then
				GuildRosterSetPublicNote(counter, note) -- Then set one
			end -- endif
		end -- endif
		
		DGPBackupNum1[name] = note -- Store the GP in the table by name
		
		counter = counter + 1
	end -- While loop
	
	DGPBackupNum1.date = date("%d/%m/20%y at %H:%M:%S") -- Add a date to the table
	
	-- Notify the user that the backup was successful and of the backups that are present
	print("Backup successful")
	print("Current backups:")
	print(DGPBackupNum1.date)
	print(DGPBackupNum2.date)
	print(DGPBackupNum3.date)
	print(DGPBackupNum4.date)
	print(DGPBackupNum5.date)
end -- dgpBackup


-- Restore one of the 5 backups, determined by the argument passed to the function
function dgpRestore(num)
	local backupTable = {} -- variable to hold the data being restored
	local counter = 1 -- Variable for counting
	
	-- Make sure the player can edit public notes
	if CanEditPublicNote() then
	else
		-- Inform user that they cannot edit GP and stop the restore
		print("Unable to edit GP notes")
		return
	end -- endif
	
	-- Determine which backup to restore
	if	num == 1 then
		backupTable = DGPBackupNum1
	elseif	num == 2 then
		backupTable = DGPBackupNum2
	elseif	num == 3 then
		backupTable = DGPBackupNum3
	elseif	num == 4 then
		backupTable = DGPBackupNum4
	elseif num == 5 then
		backupTable = DGPBackupNum5
	else -- no valid backup number given
		print("Restore NOT successful")
		return
	end -- endif
	
	-- If there was a valid backup chosen then brgin the restore
	if backupTable == {} then
	else
		print("Restoring backup " .. backupTable.date) -- Inform the user which backup date has been chosen
		
		SetGuildRosterShowOffline(true) -- Make sure offline members are shown
	
		local numMembers = GetNumGuildMembers() -- Retrieve the number of guild members (online number not required)
		
		-- Cycle through all players in the guild
		while counter <= numMembers do
	
			-- Retrieve the players guild details up to officer note
			local name, rank, rankIndex, level, class, zone, note, officernote = GetGuildRosterInfo(counter)
			
			-- Check that the name is in the backup
			if backupTable[name] == nil then -- If it isn't...
				GuildRosterSetPublicNote(counter, "GP: 0") -- Set the Guild Points to 0
			else -- If it is...
				-- Check if there is any difference between the bacjup and the current GP
				if note == backupTable[name] then 
				else -- If there is...
					print(name .. ": " .. note .. " replaced with " .. backupTable[name]) -- Inform the user of the change that is to be made
					GuildRosterSetPublicNote(counter, backupTable[name]) -- Restore the GP
				end -- endif
			end -- endif
			
			counter = counter + 1
		end -- While loop
		print("Restore successful to " .. backupTable.date) -- Report which backup was successfully restored
	end -- endif
end -- dgpRestore


-- Compare the current GP with the requested backup
function dgpCompare(num)
	local backupTable = {} -- variable to hold the data being compared
	local counter = 1 -- Variable for counting
	
	-- Determine which backup to compare
	if	num == 1 then
		backupTable = DGPBackupNum1
	elseif	num == 2 then
		backupTable = DGPBackupNum2
	elseif	num == 3 then
		backupTable = DGPBackupNum3
	elseif	num == 4 then
		backupTable = DGPBackupNum4
	elseif num == 5 then
		backupTable = DGPBackupNum5
	else -- no valid backup number given
		print("No comparison available")
		return
	end -- endif
	
	-- If there was a valid backup chosen then begin the comparison
	if backupTable == {} then
	else
		print("Comparing with backup " .. backupTable.date) -- Inform the user which backup date has been chosen
		
		SetGuildRosterShowOffline(true) -- Make sure offline members are shown
	
		local numMembers = GetNumGuildMembers() -- Retrieve the number of guild members (online number not required)
		
		-- Cycle through all players in the guild
		while counter <= numMembers do
	
			-- Retrieve the players guild details up to officer note
			local name, rank, rankIndex, level, class, zone, note, officernote = GetGuildRosterInfo(counter)
			
			-- Check that the name is in the backup
			if backupTable[name] == nil then -- If it isn't...
				print(name .. " is new to the guild")
			else -- If it is...
				-- Check if there is any difference between the backup and the current GP
				if note == backupTable[name] then 
				else -- If there is...
					print(name .. ": " .. backupTable[name] .. " -> " .. note) -- Inform the user of the change since the backup
				end -- endif
			end -- endif
			
			counter = counter + 1
		end -- While loop
		print("Comparison with backup " .. backupTable.date .. " completed")
	end -- endif
end -- dgpCompare


-- Clear the focus on the filter editbox
function dgpClearFilterFocus()
	dgp_Filter_Editbox:ClearFocus()
end --dgpClearFilterFocus


-- Clear the focus on the filter editbox
function dgpClearGPFocus()
	dgp_Editbox_GP:ClearFocus()
end --dgpClearFilterFocus


-- Change the selected menu item in the dropbox menu
function dgpFilterDropboxChangeValue(dgpFilterDropboxValue)
	UIDropDownMenu_SetSelectedValue(dgp_Filter_Dropbox, dgpFilterDropboxValue) 
end --dgpFilterDropboxChangeValue


-- Filter the selection list
function dgpFilterPlayers()
	dgp_Filtered_Guild_Members = {} -- Clear the database
	local counter = 1 -- Varible for counting
	local index = 1 -- Variable used for database indexing
	local dgpFilter = UIDropDownMenu_GetSelectedValue(dgp_Filter_Dropbox) -- Store the filter type
	local dgpFilterString = dgp_Filter_Editbox:GetText() -- Store the filter string
	
	SortGuildRoster("level") -- Sort the guild roster by level (to make sure the alphabetical sort isn't backwards)
	SetGuildRosterShowOffline(true) -- Make sure offline members are shown
	SortGuildRoster("name") -- Sort the guild roster by name
	
	local numMembers = GetNumGuildMembers() -- Retrieve the number of guild members (online number not required)
	
	-- Add selected players to the top of every list
	
	counter = 1
	index = 1
	-- Cycle through all players in the guild
	while counter <= numMembers do
	
		-- Retrieve the players guild details up to online status
		local dgp_name, dgp_rank, rankIndex, level, class, zone, dgp_note, dgp_onote = GetGuildRosterInfo(counter)
		
		if (dgp_Selected_Guild_Members[dgp_name]) then
			if dgpFilterString then -- If there is a filter string present
				if strfind(strlower(dgp_name), strlower(dgpFilterString)) then -- If the name contains the filter
					dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Then store the current player details
					index = index + 1
				end -- endif
			else -- If there is no filter string
				dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Store the current player details
				index = index + 1
			end -- endif
		end -- endif
	
		counter = counter + 1
	end -- While loop
		
	if dgpFilter == "All" then
		counter = 1
		-- Cycle through all players in the guild
		while counter <= numMembers do
	
			-- Retrieve the players guild details up to officer note
			local dgp_name, dgp_rank, rankIndex, level, class, zone, dgp_note, dgp_onote = GetGuildRosterInfo(counter)
			
			if (not dgp_Selected_Guild_Members[dgp_name]) then -- Selected players have already been added
				if dgpFilterString then -- If there is a filter string present
					if strfind(strlower(dgp_name), strlower(dgpFilterString)) then -- If the name contains the filter
						dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Then store the current player details
						index = index + 1
					end -- endif
				else -- If there is no filter string
					dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Store the current player details
					index = index + 1
				end -- endif
			end -- endif
		
			counter = counter + 1
		end -- While loop
	elseif dgpFilter == "Online" then
		counter = 1
		-- Cycle through all players in the guild
		while counter <= numMembers do
	
			-- Retrieve the players guild details up to online status
			local dgp_name, dgp_rank, rankIndex, level, class, zone, dgp_note, dgp_onote, dgp_online = GetGuildRosterInfo(counter)
			
			if (not dgp_Selected_Guild_Members[dgp_name]) then -- Selected players have already been added
				if (dgp_online == 1) then -- If the player is online
					if dgpFilterString then -- If there is a filter string present
						if strfind(strlower(dgp_name), strlower(dgpFilterString)) then -- If the name contains the filter
							dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Then store the current player details
							index = index + 1
						end -- endif
					else -- If there is no filter string
						dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Store the current player details
						index = index + 1
					end -- endif
				end -- endif
			end -- endif
		
			counter = counter + 1
		end -- While loop
	elseif dgpFilter == "Party" then
		counter = 1
		-- Cycle through all players in the guild
		while counter <= numMembers do
	
			-- Retrieve the players guild details up to online status
			local dgp_name, dgp_rank, rankIndex, level, class, zone, dgp_note, dgp_onote = GetGuildRosterInfo(counter)
			
			if (not dgp_Selected_Guild_Members[dgp_name]) then -- Selected players have already been added
				if (UnitInParty(dgp_name) == 1) then -- If the player is in your party/raid group
					if dgpFilterString then -- If there is a filter string present
						if strfind(strlower(dgp_name), strlower(dgpFilterString)) then -- If the name contains the filter
							dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Then store the current player details
							index = index + 1
						end -- endif
					else -- If there is no filter string
						dgp_Filtered_Guild_Members[index] = { name = dgp_name, rank = dgp_rank, note = dgp_note, onote = dgp_onote } -- Store the current player details
						index = index + 1
					end -- endif
				end -- endif
			end -- endif
		
			counter = counter + 1
		end -- While loop
	elseif dgpFilter == "Selected" then
		counter = 1
		-- No futher filtering required
	end -- endif	
	
	dgpUpdateSlider() -- Update the slider to match the new list size
	
end -- dgpFilterPlayers


-- Update the position of the list
function dgpUpdateList()
	local counter = 0 -- Variable for counting
	
	if(not dgp_Filtered_Guild_Members[dgp_List_Position]) then -- If the current position does not exist
		dgp_List_Position = 1 -- Then go to the start poisition of the list
	end -- endif
	
	while counter < 15 do -- Cycle through up to 15 players
		if(dgp_Filtered_Guild_Members[dgp_List_Position + counter]) then -- If there as a player to show	
			local playerName = dgp_Filtered_Guild_Members[dgp_List_Position + counter].name -- Store the player name
			local playerNote = dgp_Filtered_Guild_Members[dgp_List_Position + counter].note -- Store the player note
			-- Then show the appropriate button
			if counter == 0 then 
				dgp_Player_Listbox_Button1_1:Show()
				dgp_Player_Listbox_Button1_2:Show()
				dgp_Player_Listbox_Button1_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button1_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button1_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button1_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button1_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button1_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 1 then
				dgp_Player_Listbox_Button2_1:Show()
				dgp_Player_Listbox_Button2_2:Show()
				dgp_Player_Listbox_Button2_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button2_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button2_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button2_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button2_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button2_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 2 then 
				dgp_Player_Listbox_Button3_1:Show()
				dgp_Player_Listbox_Button3_2:Show()
				dgp_Player_Listbox_Button3_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button3_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button3_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button3_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button3_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button3_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 3 then 
				dgp_Player_Listbox_Button4_1:Show()
				dgp_Player_Listbox_Button4_2:Show()
				dgp_Player_Listbox_Button4_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button4_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button4_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button4_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button4_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button4_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 4 then 
				dgp_Player_Listbox_Button5_1:Show()
				dgp_Player_Listbox_Button5_2:Show()
				dgp_Player_Listbox_Button5_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button5_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button5_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button5_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button5_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button5_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 5 then  
				dgp_Player_Listbox_Button6_1:Show()
				dgp_Player_Listbox_Button6_2:Show()
				dgp_Player_Listbox_Button6_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button6_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button6_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button6_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button6_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button6_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 6 then 
				dgp_Player_Listbox_Button7_1:Show()
				dgp_Player_Listbox_Button7_2:Show()
				dgp_Player_Listbox_Button7_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button7_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button7_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button7_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button7_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button7_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 7 then 
				dgp_Player_Listbox_Button8_1:Show()
				dgp_Player_Listbox_Button8_2:Show()
				dgp_Player_Listbox_Button8_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button8_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button8_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button8_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button8_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button8_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 8 then 
				dgp_Player_Listbox_Button9_1:Show()
				dgp_Player_Listbox_Button9_2:Show()
				dgp_Player_Listbox_Button9_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button9_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button9_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button9_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button9_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button9_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 9 then 
				dgp_Player_Listbox_Button10_1:Show()
				dgp_Player_Listbox_Button10_2:Show()
				dgp_Player_Listbox_Button10_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button10_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button10_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button10_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button10_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button10_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 10 then 
				dgp_Player_Listbox_Button11_1:Show()
				dgp_Player_Listbox_Button11_2:Show()
				dgp_Player_Listbox_Button11_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button11_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button11_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button11_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button11_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button11_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 11 then 
				dgp_Player_Listbox_Button12_1:Show()
				dgp_Player_Listbox_Button12_2:Show()
				dgp_Player_Listbox_Button12_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button12_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button12_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button12_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button12_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button12_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 12 then 
				dgp_Player_Listbox_Button13_1:Show()
				dgp_Player_Listbox_Button13_2:Show()
				dgp_Player_Listbox_Button13_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button13_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button13_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button13_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button13_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button13_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 13 then 
				dgp_Player_Listbox_Button14_1:Show()
				dgp_Player_Listbox_Button14_2:Show()
				dgp_Player_Listbox_Button14_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button14_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button14_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button14_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button14_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button14_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			elseif counter == 14 then 
				dgp_Player_Listbox_Button15_1:Show()
				dgp_Player_Listbox_Button15_2:Show()
				dgp_Player_Listbox_Button15_1.text:SetText(playerName) -- Add the player name to the left button
				dgp_Player_Listbox_Button15_2.text:SetText(playerNote) -- Add the player note to the right button
				if (dgp_Selected_Guild_Members[playerName]) then -- If the player is a selected player
					dgp_Player_Listbox_Button15_1.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
					dgp_Player_Listbox_Button15_2.texture:SetTexture(0.1, 0.2, 1.0, 0.25)-- Change the button background
				else -- If the player isn't selected
					dgp_Player_Listbox_Button15_1.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
					dgp_Player_Listbox_Button15_2.texture:SetTexture(1.0, 1.0, 1.0, 0.1)-- Change the button background back
				end -- endif
			end -- endif (switch)
		else -- If there is no player to show
			-- Then hide the appropriate button
			if counter == 0 then		dgp_Player_Listbox_Button1_1:Hide()
								dgp_Player_Listbox_Button1_2:Hide()
			elseif counter == 1 then 	dgp_Player_Listbox_Button2_1:Hide()
								dgp_Player_Listbox_Button2_2:Hide()
			elseif counter == 2 then 	dgp_Player_Listbox_Button3_1:Hide()
								dgp_Player_Listbox_Button3_2:Hide()
			elseif counter == 3 then 	dgp_Player_Listbox_Button4_1:Hide()
								dgp_Player_Listbox_Button4_2:Hide()
			elseif counter == 4 then 	dgp_Player_Listbox_Button5_1:Hide()
								dgp_Player_Listbox_Button5_2:Hide()
			elseif counter == 5 then 	dgp_Player_Listbox_Button6_1:Hide()
								dgp_Player_Listbox_Button6_2:Hide()
			elseif counter == 6 then 	dgp_Player_Listbox_Button7_1:Hide()
								dgp_Player_Listbox_Button7_2:Hide()
			elseif counter == 7 then 	dgp_Player_Listbox_Button8_1:Hide()
								dgp_Player_Listbox_Button8_2:Hide()
			elseif counter == 8 then 	dgp_Player_Listbox_Button9_1:Hide()
								dgp_Player_Listbox_Button9_2:Hide()
			elseif counter == 9 then 	dgp_Player_Listbox_Button10_1:Hide()
								dgp_Player_Listbox_Button10_2:Hide()
			elseif counter == 10 then 	dgp_Player_Listbox_Button11_1:Hide()
								dgp_Player_Listbox_Button11_2:Hide()
			elseif counter == 11 then 	dgp_Player_Listbox_Button12_1:Hide()
								dgp_Player_Listbox_Button12_2:Hide()
			elseif counter == 12 then 	dgp_Player_Listbox_Button13_1:Hide()
								dgp_Player_Listbox_Button13_2:Hide()
			elseif counter == 13 then 	dgp_Player_Listbox_Button14_1:Hide()
								dgp_Player_Listbox_Button14_2:Hide()
			elseif counter == 14 then 	dgp_Player_Listbox_Button15_1:Hide()
								dgp_Player_Listbox_Button15_2:Hide()
			end -- endif (switch)
		end -- endif
		
		counter = counter + 1
	end -- While loop
	
end -- dgpUpdateList


-- Select/Deslect player for the associated button
function dgpToggleSelectPlayer(num)
	if dgp_Filtered_Guild_Members[dgp_List_Position + num -1] then -- If the button has an associated player
		local playerName = dgp_Filtered_Guild_Members[dgp_List_Position + num -1].name -- Store the associated player's name
		
		if dgp_Selected_Guild_Members[playerName] then -- If the player is already selected
			dgp_Selected_Guild_Members[playerName] = nil -- Then deselect them
			
			-- Check if the deselecting the player will create an empty space.
			-- If so then move the slider back one (if possible)
			if UIDropDownMenu_GetSelectedValue(dgp_Filter_Dropbox) == "Selected" then
				if(dgp_Player_Listbox_Slider:GetValue() > 1) then
					if(dgp_Player_Listbox_Slider:GetValue() > #(dgp_Filtered_Guild_Members) - 15) then
						dgp_Player_Listbox_Slider:SetValue(dgp_Player_Listbox_Slider:GetValue()-1)
					end --endif
				end --endif
			end -- endif
			
		else -- If the player isn't selected
			dgp_Selected_Guild_Members[playerName] = 1 -- Then select them
		end -- endif
		
		dgpFilterPlayers()
		dgpUpdateList()
	end -- endif
end -- dgpToggleSelectPlayer


-- Update the slider based on the filterbox contents
function dgpUpdateSlider()
	if(dgp_Player_Listbox_Slider:GetValue() > #(dgp_Filtered_Guild_Members) - 14) then -- If the value of the slider is too high
		dgp_Player_Listbox_Slider:SetValue(1) -- Then reset the slider to position 1
		dgp_List_Position = 1 -- Go to the start poisition of the list
	end -- endif
	
	if(#(dgp_Filtered_Guild_Members) > 15) then
		dgp_Player_Listbox_Slider:SetMinMaxValues(1, #(dgp_Filtered_Guild_Members) - 14) -- Adjust the scale to the number of players on the list
		dgp_Player_Listbox_Slider:SetValue(dgp_List_Position) -- make sure the value doesn't get changed
	else
		dgp_Player_Listbox_Slider:SetMinMaxValues(1, 1)
		dgp_List_Position = 1 -- Go to the start poisition of the list
	end -- endif
	
end -- dgpUpdateSlider


-- Toggle the Full Guild Run Modifier
function dgpToggleFullGuild()
	-- Toggle the full guild option
	if dgp_Full_Guild == 0 then
		dgp_Full_Guild = 1
		dgp_Button_Full_Guild.texture:SetTexture(0.1, 0.2, 1.0, 0.25)
	else
		dgp_Full_Guild = 0
		dgp_Button_Full_Guild.texture:SetTexture(1.0, 1.0, 1.0, 0.1)
	end -- endif
	
end -- dgpFullGuild


-- Add guild points to the select player(s)
function dgpAddPoints(num)
	local counter = 1 -- Variable for counting
	local numMembers = GetNumGuildMembers() -- Retrieve the number of guild members (online number not required)
	
	dgpFadeOut() -- Fade out the addon
	dgp_List_Position = 1 -- Scroll back to the top
	
	if dgp_Full_Guild  == 1 then
		num = num + num -- If it is a full guild run then double the points
	end -- endif
	
	SetGuildRosterShowOffline(true) -- Make sure offline members are shown
	
	-- Cycle through all players in the guild
	while counter <= numMembers do
	
		-- Retrieve the players guild details up to note
		local dgp_name, dgp_rank, rankIndex, level, class, zone, dgp_note = GetGuildRosterInfo(counter)
		
		if dgp_Selected_Guild_Members[dgp_name] then -- If the current player is selected
			local currentPoints = tonumber( strsub(dgp_note, 5) ) -- Issolate the points formt he player's note
			local newPoints = "GP: " .. currentPoints + num -- Add the new points and convert it back to a note
			
			GuildRosterSetPublicNote(counter, newPoints) -- Set the new points
		end --endif
	
		counter = counter + 1
	end -- While loop	
	
	-- Update the filter list after 1 second
	dgp_wait(1, dgpFilterPlayers)
	dgp_wait(1, dgpUpdateList)
	dgp_wait(2, dgpFadeIn)
end -- dgpAddPoints


-- Remove guild points fromt he selected player(s)
function dgpSubtractPoints(num)
	local counter = 1 -- Variable for counting
	local numMembers = GetNumGuildMembers() -- Retrieve the number of guild members (online number not required)
	
	dgpFadeOut() -- Fade out the addon
	dgp_List_Position = 1 -- Scroll back to the top
	
	SetGuildRosterShowOffline(true) -- Make sure offline members are shown
	
	-- Cycle through all players in the guild
	while counter <= numMembers do
	
		-- Retrieve the players guild details up to note
		local dgp_name, dgp_rank, rankIndex, level, class, zone, dgp_note = GetGuildRosterInfo(counter)
		
		if dgp_Selected_Guild_Members[dgp_name] then -- If the current player is selected
			local currentPoints = tonumber( strsub(dgp_note, 5) ) -- Issolate the points formt he player's note
			
			if currentPoints - num < 0 then -- Change num to stop points going below 0
				num = currentPoints
			end --endif
			
			local newPoints = "GP: " .. currentPoints - num -- Subtract the new points and convert it back to a note
			
			GuildRosterSetPublicNote(counter, newPoints) -- Set the new points
		end --endif
	
		counter = counter + 1
	end -- While loop
	
	-- Update the filter list after 1 second
	dgp_wait(1, dgpFilterPlayers)
	dgp_wait(1, dgpUpdateList)
	dgp_wait(2, dgpFadeIn)	
end -- dgpSubtractPoints

-- Hide the fading frame
function dgpFadeIn()
	dgp_Fade_Frame:SetFrameLevel(1) -- Hide the fade frame behind the rest of the addon
end -- dgpFadeIn

-- Show the fading frame, disabling all buttons beneath it
function dgpFadeOut()
	dgp_Fade_Frame:SetFrameLevel(20) -- Bring the fade frame to the front
end -- dgpFadeOut

